@@ -25,7 +25,7 @@ repeat = '<{' \
          '[![!{can,will,could} you]? say {that,it} again],' \
          '[!what did you, just? say],' \
          '[!what was that]' \
-         '}, #CNC(movies), #CNC(music), #CNC(nba), #CNC(news)> #COPY(__goal_return_state__)'
+         '}, #CNC(movies), #CNC(music), #CNC(sports), #CNC(external_news)> #COPYGR'
 
 global_update_rules = {
     '#CONTRACTIONS': '',
