@@ -6,7 +6,6 @@ from copy import deepcopy
 backstory = DialogueFlow('_local_start')
 backstory.add_system_transition('exit', 'SYSTEM:root', '#GCOM(backstory)')
 backstory.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
-backstory.knowledge_base().load_json_file(PATHDIR.replace('__***__', 'backstory.json'))
 backstory.add_system_transition('_local_start', 'start', '')
 
 system = {
@@ -131,41 +130,70 @@ ask_how = {
 preferences = {
     'state': 'unknown_preferences',
 
-    '`You know, I haven\'t really thought about it. Do you like it?`': {
+    '`You know, I haven\'t made up my mind yet. What about you?`'
+    '#GATE': {
+        'score': 1.1,
         'state': 'share_unknown_pref',
 
-        '#AGREE':{
+        '{#AGREE, [i,#NOT(not),{do,#EXP(like)}]}':{
             'state': 'unknown_pref_agree',
 
-            '`Okay, I will keep that in mind. `':{
+            '`You do? Now I really want to know why! I would love to hear more about what is so good about it. `':{
                 'state': 'unknown_pref_agree_r',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'unknown_pref_agree_unx'}
+                '#IDK': {
+                    'state': 'unknown_pref_agree_idk',
+
+                    '`That\'s fine. I will just have to look into it more myself. `#GRET':
+                        'exit'
+                },
+
+                '#UNX(None)': {
+                    'state': 'unknown_pref_agree_unx',
+
+                    '`I see. Well, I will have to keep that in mind. ` #GRET':
+                        'exit'
+                }
             }
         },
 
-        '#DISAGREE':{
+        '{#DISAGREE, [i,do not,#EXP(like)?], [i,{hate,dislike,detest}]}':{
             'state': 'unknown_pref_disagree',
 
-            '`You don\'t? That\'s good to know. `': {
+            '`You don\'t? Why not? `': {
                 'state': 'unknown_pref_disagree_r',
 
-                '#UNX': {'#GRET': 'exit', 'state': 'unknown_pref_disagree_unx'}
+                '#IDK': {
+                    'state': 'unknown_pref_disagree_idk',
+
+                    '`That\'s fine. I will just have to get more opinions from others. `#GRET':
+                        'exit'
+                },
+
+                '#UNX(None)': {
+                    'state': 'unknown_pref_disagree_unx',
+
+                    '`I see. Well, that is good to know. ` #GRET':
+                        'exit'
+                }
             }
         },
 
-        '#IDK':{
+        '{#IDK,[[! me {neither,either,too}]]}':{
             'state': 'unknown_pref_idk',
 
-            '`Well, keep me in the loop if you ever figure it out! `': {
-                'state': 'unknown_pref_idk_r',
-
-                '#UNX': {'#GRET': 'exit', 'state': 'unknown_pref_idk_unx'}
-            }
+            '`Well, keep me in the loop if you ever figure it out! ` #GRET':
+                'exit'
         },
 
-        '#UNX': {'#GRET': 'exit', 'state': 'unknown_pref_unx'}
-    }
+        '#UNX(Gotcha)': {'#GRET': 'exit', 'state': 'unknown_pref_unx'}
+    },
+
+    '`I actually haven\'t given it that much thought. What about you?` #GATE': 'share_unknown_pref',
+
+    '`I haven\'t really thought about that. What about you?` #GATE': 'share_unknown_pref',
+
+    '`I\'m still trying to figure out my opinion on that. What about you?`': 'share_unknown_pref'
 }
 
 emora_activities = {
