@@ -5,12 +5,11 @@ from emora_stdm import DialogueFlow
 
 relationships = DialogueFlow('_local_start')
 relationships.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
-relationships.knowledge_base().load_json_file(PATHDIR.replace('__***__', 'relationships.json'))
 relationships.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'dating',
-    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) #ANY($in_high_school=True,$in_college=True)',
+    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) #IF($life_in=True,$life_started=True) #ANY($in_high_school=True,$in_college=True)',
 
     '#DEFAULT': {
         'state': 'default_relationship',
@@ -23,10 +22,10 @@ system = {
     '#GSRET(default_relationship)':{
         'state': 'ask_relationship',
 
-        '#AGREE':
+        '{#AGREE,[{[!-not,{correct,true,right}],[!i am,-not]}]}':
             'dating_y',
 
-        '[{#DISAGREE,[not dating],noone,no one,nobody,[!not,{have,got},{a,any},#ONT(partner)]}]':
+        '[{#DISAGREE,[i am not],[not dating],noone,no one,nobody,[!not,{have,got},{a,any},#ONT(partner)]}]':
             'single',
 
         '[#NOT(not),{$partner=#ONT(spouse),#LEM(marry)}]'
@@ -83,13 +82,13 @@ system = {
             '`I\'m so sorry to hear that your relationship ended. Are you doing okay?`': {
                 'state': 'broke_up_r',
 
-                '{#AGREE,[#NEGATION,#ONT(_negative adj)],[-#NEGATION,#ONT(_positive adj)]}': {
+                '{#AGREE,[#NEGATION,#ONT(_negative adj)],[!-#NEGATION [#ONT(_positive adj)]]}': {
                     'state': 'broke_up_feeling_ok',
 
                     '`That\'s a relief to hear, I am so glad you are doing alright. `':  'exit'
                 },
 
-                '{#DISAGREE,[-#NEGATION,#ONT(_negative adj)],[#NEGATION,#ONT(_positive adj)]}': {
+                '{#DISAGREE,[! -#NEGATION [#ONT(_negative adj)]],[#NEGATION,#ONT(_positive adj)]}': {
                     'state': 'broke_up_feeling_bad',
 
                     '`Oh no... I feel for you. I know break ups can be tough, but I believe that better '
@@ -121,13 +120,13 @@ system = {
             'doing now?`': {
                 'state': 'divorced_r',
 
-                '{[#NEGATION,#ONT(_negative adj)],[-#NEGATION,#ONT(_positive adj)]}': {
+                '{[#NEGATION,#ONT(_negative adj)],[!-#NEGATION [#ONT(_positive adj)]]}': {
                     'state': 'divorced_ok',
 
                     '`That\'s a relief to hear, I am so glad you are doing alright. `': 'exit'
                 },
 
-                '{[-#NEGATION,#ONT(_negative adj)],[#NEGATION,#ONT(_positive adj)]}': {
+                '{[! -#NEGATION [#ONT(_negative adj)]],[#NEGATION,#ONT(_positive adj)]}': {
                     'state': 'divorced_bad',
 
                     '`Oh no... I feel for you. I know it can be so tough to continue on, but I believe that better '
@@ -156,7 +155,7 @@ system = {
             '`Oh. I\'m so sorry for your loss. I cannot even imagine what you are going through. I hope you are doing ok. `': {
                 'state': 'partner_died_r',
 
-                '{[#NEGATION,#ONT(_negative adj)],[-#NEGATION,#ONT(_positive adj)]}': {
+                '{[#NEGATION,#ONT(_negative adj)],[!-#NEGATION [#ONT(_positive adj)]]}': {
                     'state': 'partner_died_ok',
 
                     '`That\'s reassuring, I am so glad you are doing alright. '
@@ -164,7 +163,7 @@ system = {
                         'exit'
                 },
 
-                '{[-#NEGATION,#ONT(_negative adj)],[#NEGATION,#ONT(_positive adj)]}': {
+                '{[! -#NEGATION [#ONT(_negative adj)]],[#NEGATION,#ONT(_positive adj)]}': {
                     'state': 'partner_died_bad',
 
                     '`Oh no... I feel for you. I know it can be so tough to continue on, but '
@@ -201,7 +200,10 @@ system = {
 
                 'error':{
 
-                    '`I see. Well, I hope it clears up soon for you. It is a frustrating situation to feel that way. `': 'exit'
+                    '`I see. Well, I hope it clears up soon for you. It is a frustrating situation to feel that way. `': {
+
+                        '#UNX': 'exit'
+                    }
                 }
             }
         },
@@ -246,7 +248,7 @@ friend_married = {
 
 marriage = {
     'state': 'marriage',
-    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) #ANY($is_student=False,$is_student=None)',
+    'enter': '#GATE #GCOM(relationship) #GOAL(relationship) #IF($life_in=True,$life_started=True) #ANY($is_student=False,$is_student=None)',
 
     '#DEFAULT': {
         'state': 'default_marriage',
@@ -259,7 +261,7 @@ marriage = {
     '#GSRET(default_marriage)': {
         'state': 'asked_married',
 
-        '#AGREE'
+        '{#AGREE,[[!-not,{correct,true}]],[[!i am,-not]]}'
         '#SET($relationship_status=married)': {
             'state': 'married_y',
 
@@ -352,7 +354,19 @@ marriage = {
             }
         },
 
-        '#DISAGREE':{
+        '[#LEM(divorce,separate)]'
+        '#SET($relationship_status=divorced)': {
+            'state': 'divorced',
+            'score': 1.2
+        },
+
+        '[{death,#LEM(die),passed away,killed,murdered,lost}]'
+        '#SET($relationship_status=partner_died)': {
+            'state': 'partner_died',
+            'score': 1.2
+        },
+
+        '{#DISAGREE,[i am not]}':{
             'state': 'married_n',
 
             '`That\'s alright. It is hard to find the right person. Are you currently seeing anyone?`'
@@ -375,7 +389,7 @@ wedding_talk = {
     '`What was your wedding like when you got married?`':{
         'state': 'describe_wedding',
 
-        '{[#NEGATION,#ONT(_negative adj)],[-#NEGATION,#ONT(_positive adj)]}':{
+        '{[#NEGATION,#ONT(_negative adj)],[!-#NEGATION [{best,#ONT(_positive adj)}]]}':{
 
             '`Awesome! What a great memory. It seems like a really good time. Would you consider it '
             'one of the best moments of your life?`'
@@ -383,7 +397,7 @@ wedding_talk = {
                 'best_moment'
         },
 
-        '<#TOKLIMIT(4), {[-#NEGATION,#ONT(_negative adj)],[#NEGATION,#ONT(_positive adj)]}>': {
+        '<#TOKLIMIT(4), {[!-#NEGATION [#ONT(_negative adj)]],[#NEGATION,#ONT(_positive adj)]}>': {
 
             '`Oh no! What went wrong?`'
             '#GSRET(exit)': {
@@ -395,7 +409,7 @@ wedding_talk = {
             }
         },
 
-        '{[-#NEGATION,#ONT(_negative adj)],[#NEGATION,#ONT(_positive adj)]}': {
+        '{[!-#NEGATION [#ONT(_negative adj)]],[#NEGATION,#ONT(_positive adj)]}': {
             'score': 1.1,
 
             '`That\'s terrible! What would you do differently, if you could do it all over again?`'
@@ -404,7 +418,10 @@ wedding_talk = {
                 '#UNX': {
                     'state': 'keep_in_mind',
 
-                    '`Well, I\'ll have to keep that in mind if I ever think of getting married one day.`': 'exit'
+                    '`Well, I\'ll have to keep that in mind if I ever think of getting married one day.`':{
+
+                        '#UNX': 'exit'
+                    }
                 }
             }
         },
@@ -423,7 +440,10 @@ wedding_talk = {
                 '#DISAGREE':{
 
                     '`I see. You must have lots of other really good memories then. '
-                    'I hope you still look back on your wedding day fondly too. `': 'exit'
+                    'I hope you still look back on your wedding day fondly too. `': {
+
+                        '#UNX': 'exit'
+                    }
                 },
 
                 '#UNX(None)':{
@@ -444,7 +464,7 @@ wedding_planning = {
     '`How has planning the wedding been going?`': {
         'state': 'describe_planning',
 
-        '{[-#NEGATION,#ONT(_negative adj)],[#NEGATION,#ONT(_positive adj)]}': {
+        '{[!-#NEGATION [#ONT(_negative adj)]],[#NEGATION,#ONT(_positive adj)]}': {
 
             '`I see, well don\'t worry too much about it. '
             'I\'m sure you\'ll be so happy to be married.`'
@@ -457,7 +477,7 @@ wedding_planning = {
             }
         },
 
-        '{[#NEGATION,#ONT(_negative adj)],[-#NEGATION,#ONT(_positive adj)]}': {
+        '{[#NEGATION,#ONT(_negative adj)],[!-#NEGATION [#ONT(_positive adj)]]}': {
 
             '`That\'s great, in my experience it\'s not always the most fun thing. '
             'I helped one of my friends plan their wedding a little bit, and I know they had a lot of work to do.`'
@@ -550,6 +570,31 @@ user = {
         }
     },
 
+    # what was their wedding like
+    '[{what,how},{they,their,friend,friends},{ceremony,reception,wedding}]': {
+        'state': 'friend_wedding_describe_q',
+        'score': 9.9,
+
+        '`It was one of the most beautiful things I have seen. It fit them so well, since they '
+        'kept it pretty small and had it on a beach, and they both love the ocean. `': {
+            'state': 'friend_wedding_describe',
+
+            '#UNX': {'#GRET': 'exit', 'state': 'friend_wedding_describe_unx'}
+        }
+    },
+
+    # how long together
+    '[{how long},{they,their,friend,friends},{together,a couple,an item}]': {
+        'state': 'friend_couple_length_q',
+
+        '`I think they have known each other for about six months. It was a whirlwind romance, but I think they '
+        'know what they are doing. They are really happy together. `': {
+            'state': 'friend_couple_length',
+
+            '#UNX': {'#GRET': 'exit', 'state': 'friend_couple_length_unx'}
+        }
+    },
+
     #how big was ceremony
     '<{small,big,size,[many,{people,guests}]},{they,their,friend,friends},{married,wedding}>': {
         'state': 'friend_wedding_size_q',
@@ -612,7 +657,7 @@ user = {
     },
 
     #are you married
-    '[#NOT(want,wish,hope,desire),{you,your},{married,wedding}]': {
+    '[#NOT(want,wish,hope,desire),{have,are,did},{you,your},{married,wedding}]': {
         'state': 'emora_married_q',
 
         '`I am not married. I\'ve actually never dated before. I\'m not in any rush. `': {
@@ -658,12 +703,7 @@ user = {
                 '`Oh, no way! It\'s too real if I tell you that. I cannot believe we are even talking about this. `': {
                     'state': 'crush_name_r',
 
-                    '#UNX(None)': {
-                        'state': 'crush_name_unx',
-
-                        '`Oh my gosh, I am so flustered thinking about this right now. '
-                        'We should really talk about something else. Anyways,` #GRET': 'exit'
-                    }
+                    '#UNX(None)': 'about_crush_unx'
                 }
             },
 
@@ -673,16 +713,11 @@ user = {
                 '`What! I can\'t do that. What if he doesn\'t like me too?`': {
                     'state': 'tell_crush_r',
 
-                    '#UNX(None)': {
-                        'state': 'tell_crush_unx',
-
-                        '`Oh my gosh, I am so flustered thinking about this right now. '
-                        'We should really talk about something else. Anyways,` #GRET': 'exit'
-                    }
+                    '#UNX(None)': 'about_crush_unx'
                 }
             },
 
-            '{[why],[what,he,like],[tell me more,tell me about]}': {
+            '{[why],[what,he,like],[{tell me more,tell me about}]}': {
                 'state': 'about_crush',
 
                 '`He is really funny and such a kind person. He volunteers at the dog shelter and all animals love him. '
@@ -693,7 +728,7 @@ user = {
                         'state': 'about_crush_unx',
 
                         '`Oh my gosh, I am so flustered thinking about this right now. '
-                        'We should really talk about something else. Anyways,` #GRET': 'exit'
+                        'We should really talk about something else. So,` #GRET': 'exit'
                     }
                 }
             },
@@ -702,7 +737,7 @@ user = {
                 'state': 'emora_crush_unx',
 
                 '`I cannot believe I told you that. '
-                'We should really talk about something else. Anyways,` #GRET': 'exit'
+                'We should really talk about something else. So,` #GRET': 'exit'
             }
         }
     },
