@@ -5,12 +5,11 @@ from emora_stdm import DialogueFlow
 
 sibling = DialogueFlow('_local_start')
 sibling.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
-sibling.knowledge_base().load_json_file(PATHDIR.replace('__***__', 'sibling.json'))
 sibling.add_system_transition('_local_start', 'start', '')
 
 siblings = {
     'state': 'start',
-    'enter': '#GATE #GCOM(sibling) #GOAL(sibling)',
+    'enter': '#GATE #GCOM(sibling) #GOAL(sibling) #IF($life_in=True,$life_started=True)',
 
     '#IF($sibling=None)': 'ask_sibling',
 
@@ -32,7 +31,7 @@ known_siblings = {
         }
     },
 
-    '`So you said you live with your` $sibling=#I($lives_with, #U(brother, sister, brothers, sisters)) ` right? '
+    '`So, earlier you mentioned your` $sibling=#I($lives_with, #U(brother, sister, brothers, sisters)) ` right? '
     'Do you guys get along?`'
     '#GSRET(default_known_start)': {
         'state': 'sibling',
@@ -40,9 +39,13 @@ known_siblings = {
         '[#NOT(not), {#AGREE,we do,most,mostly,sometime,sometimes,all the time,forever,every day,usually,frequently,get along}]'
         '#SET($gets_along_with_sibling=True)': {
 
+            '#DEFAULT `That\'s awesome. Personally, I always wanted an older sister so I could have someone to look '
+            'up to. Are you older than your sibling?`': 'sibling_younger',
+
             '`That\'s awesome. Personally, I always wanted an older sister so I could have '
             'someone to look up to. Are you older than your ` $sibling `?`'
             '#GSRET(fave_memory)': {
+                'state': 'sibling_younger',
 
                 '#AGREE'
                 '#SET($older_child=True)': {
@@ -60,6 +63,14 @@ known_siblings = {
                     '#ISP($sibling) #GSRET(fave_memory)': {
                         'score': 1.1,
 
+                        '#UNX': 'fave_memory'
+                    },
+
+                    '`You know you seem really nice, and smart. '
+                    'I bet your sibling looks up to you, even if you don\'t realize it.`'
+                    '#GSRET(fave_memory)': {
+                        'score': 0.9,
+
                         '#UNX': 'fave_memory'
                     }
                 },
@@ -77,6 +88,9 @@ known_siblings = {
         '[{#DISAGREE,not at all,never,mostly not,usually not,not usually,[we,#NOT(not),fight],[not,get along]}]'
         '#SET($gets_along_with_sibling=False)': {
 
+            '#DEFAULT `That kind of sounds like my friend Grace, she loves her younger brother but they fight all the '
+            'time. What does your sibling do that bothers you?`': 'do_not_get_along',
+
             '`That kind of sounds like my friend Grace, she loves her younger brother '
             'but they fight all the time. What do your ` $sibling ` do that bothers you?`'
             '#ISP($sibling) #GSRET(exit)': {
@@ -125,7 +139,7 @@ unknown_siblings = {
         '{#AGREE,[i do, #NOT(not)]}':{
             'state': 'sibling_y',
 
-            '`Oh cool. Do you have a sister or brother?`'
+            '`I thought you might! Do you have a sister or brother?`'
             '#GSRET(default_known_start)':{
                 'state': 'sibling_type_q',
 
@@ -180,11 +194,14 @@ unknown_siblings = {
         '#UNX(None)':{
             'state': 'clarify_sibling',
 
-            '`Sorry, I don\'t think I heard you correctly. What siblings do you have?`'
+            '`So, I don\'t think I heard your answer earlier. What siblings do you have?`'
             '#GATE':
                 'not_heard_sibling_yet',
 
-            '`Okay, that is good to know. `': 'exit'
+            '`Okay, that is good to know. `': {
+                'state': 'exit',
+                'score': 0.9
+            }
         }
 
     }
@@ -193,12 +210,16 @@ unknown_siblings = {
 fave_memory = {
     'state': 'fave_memory',
 
+    '#DEFAULT `So, tell me, what is the most fun you\'ve '
+    'ever had with your sibling?`':
+        'fave_memory_r',
+
     '`So tell me, what is the most fun you\'ve ever '
     'had with your ` $sibling `?`'
     '#GSRET(exit)': {
         'state': 'fave_memory_r',
 
-        '<#AGREE #TOKLIMIT(2)>'
+        '<#AGREE, #TOKLIMIT(2)>'
         '#GATE': {
 
             '`Really? What did you guys do?`': 'fave_memory_r'
@@ -223,7 +244,7 @@ only_child = {
     '`Do you wish you had siblings?`':{
         'state': 'want_siblings_q',
 
-        '[{#AGREE,nice,cool,good,#EXP(like)}]'
+        '{#AGREE,[{nice,cool,good,#EXP(like)}]}'
         '#SET($wants_siblings=True)':{
             'state': 'want_siblings_y',
 
@@ -235,6 +256,17 @@ only_child = {
             'state': 'want_siblings_n',
 
             '`Being an only child definitely has its perks, so I get that.  `': 'exit'
+        },
+
+        '#UNX': {
+            'state': 'want_siblings_unx',
+
+            '`That\'s an interesting response. Siblings can be your best friend or they can be a pain, so it is hard to '
+            'decide. `' :{
+                'state': 'want_siblings_unx_r',
+
+                '#UNX': 'exit'
+            }
         }
     }
 }
