@@ -32,15 +32,17 @@ def NatexMacro(natex_string):
             return bool(match)
     return _CommonNatex
 
-agree = '[!-{not, "don\'t", dont, "isn\'t", isnt} {{sure, i know, "I know"}' \
+agree = '[! -not {' \
+        'sure, i know,' \
         '[{yes, yeah, yea, yep, yup, think so, i know, absolutely, exactly, precisely, ' \
-        'certainly, surely, definitely, probably, true, of course, right}]}]'
+        'certainly, surely, definitely, probably, true, of course, right}]' \
+        '}]'
 Agree = CommonNatexMacro(agree)
 
 disagree = '{' + ', '.join([
-    '[{no, nay, nah, not really, nope, no way, wrong}]',
-    '[{absolutely, surely, definitely, certainly, i think} {not}]',
-    '[i {dont, "don\'t", do not} think so]',
+    '[{no, nay, nah, na, not really, nope, no way, wrong}]',
+    '[{absolutely, surely, definitely, certainly, i think} not]',
+    '[i, do not, think so]',
     '[not true]'
 ]) + '}'
 Disagree = CommonNatexMacro(disagree)
@@ -113,9 +115,8 @@ class Unexpected(Macro):
                 vars['__response_prefix__'] = question_response
             else:
                 vars['_explained_stupidity_'] = 'True'
-                vars['__response_prefix__'] = 'Sorry, I don\'t think I understand your question. ' \
-                                              'There\'s still a lot I\'m trying to figure out. '
-        elif len(ngrams.text().split()) < 2 and len(args) == 0:
+                vars['__response_prefix__'] = 'I\'m not sure.'
+        elif len(ngrams.text().split()) < 3 and len(args) == 0:
             vars['__response_prefix__'] = ''
             return True
         else:
@@ -129,6 +130,7 @@ class Unexpected(Macro):
             vars['__response_prefix__'] = statement_response
         return True
 
+
 natex_macros_common = {
     'AGREE': Agree(),
     'DISAGREE': Disagree(),
@@ -141,7 +143,7 @@ natex_macros_common = {
     'NOTINTERESTED': NotInterested(),
     'INTERESTED': Interested(),
     'UNX': Unexpected(),
-    'PRIVATE': DeclineShare()
+    'PRIVATE': DeclineShare(),
 }
 
 if __name__ == '__main__':
